/*****************************************************************************
 * int_types.h: internal types
 *****************************************************************************
 * Copyright (C) 1999, 2000 VideoLAN
 * $Id: int_types.h,v 1.7 2001/05/31 01:37:08 sam Exp $
 *
 * Authors: Vincent Seguin <seguin@via.ecp.fr>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
 *****************************************************************************/

/* Basic types definitions */
typedef unsigned char           u8;
typedef signed char             s8;
typedef unsigned short          u16;
typedef signed short            s16;
typedef unsigned int            u32;
typedef signed int              s32;
#if defined( _MSC_VER )
typedef unsigned __int64        u64;
typedef signed __int64          s64;
#else
typedef unsigned long long      u64;
typedef signed long long        s64;
#endif
